The goal of eventful is to streamline the process of running single-firm rolling-window event studies. It provides a single function rolling_event_study (for now). This function takes as input a formula, a dataframe, and several additional options (width of rolling window, dates to exclude in estimation, dates for which to generate dummy variables, and more), and returns a nested dataframe structure.
Maintainer: Levi Moneyhun levi.moneyhun@gmail.com
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.